| Home | Libraries | People | FAQ | More

## Acknowledgements

Thanks go to the following people for supporting the development of this library in one or the other way:

- David Abrahams
- Tom Brinkman
- Aleksey Gurtovoy
- Jody Hagins
- Hartmut Kaiser
- Andy Little
- John Maddock
- Paul Mensonides
- Alexander Nasonov
- Richard Smith
- Rob Stewart
- Jonathan Turkanis
- Pavel Vozenilek
- Steven Watanabe
- K. Noel Belcourt